YARP 2.2.6 (2010-01-20)                                                {#v2_2_6}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.2.5...v2.2.6`):

```
    26	Lorenzo Natale <lorenzo.natale@iit.it>
     9	Paul Fitzpatrick <paulfitz@alum.mit.edu>
     3	Ugo Pattacini <ugo.pattacini@iit.it>
     1	Arjan Gijsberts <arjan.gijsberts@idiap.ch>
```
